####################################################################;
# MONTECARLO SIMULATION:  NULL OLS MODEL; 
####################################################################;

# Monte Carlo Simulation of the paper "Panel Quantile Effects Via Distribution Regression"
# Authors: V. Chernozhukov, I. Fernandez-Val, M. Weidner

# Source: Helpman, Melitz, Rubinstein: "Estimating Trade Flows: Trading Partners and Trading Volumes, 2008,
# QJE, 123(2), pp. 441-487;

# Data: Helpman and Melitz web site;

# Std errors assume correct specification;

# 100% increase in distance;

# Source directory in SCC "/project/ivangrp/PDR/";

rm(list=ls());


load("EmpApp_Est.RData");
source("PDR_Source.R");


#######################
# OLS Null Parameters #
#######################
ols <- lm(model.spec, data=trade.data);
sigma.ols <- sqrt(mean(residuals(ols)^2));
theta.ols <- coefficients(ols)/sigma.ols*pi/sqrt(3);
ys.ols <- ys/sigma.ols*pi/sqrt(3);


PDR.F.null <- function(index, model.spec, data.local, ys, theta.null, t.log2, t.d){
  y <- ys[index];
  
  n.obs <- NROW(data.local);
  
  w <- model.matrix(model.spec, data.local);
  lin <- w %*% as.vector(theta.null);
  
  F.log2.0 <- rep(0,length(t.log2));
  F.log2.1 <- rep(0,length(t.log2));
  
  for(i in 1:length(t.log2)){
    F.log2.0[i] <- sum(plogis(y - lin), na.rm=T)/n.obs; 
    F.log2.1[i] <- sum(plogis(y - (lin + log(2)* theta.null[t.log2[i]])), na.rm=T)/n.obs;
  };
  
  
  F.d.0 <- rep(0,length(t.d));
  F.d.1 <- rep(0,length(t.d));
  
  for(i in 1:length(t.d)){
    F.d.0[i] <- sum(plogis(y - (lin - w[,t.d[i]]*theta.null[t.d[i]])), na.rm=T)/n.obs; 
    F.d.1[i] <- sum(plogis(y - (lin + (1-w[,t.d[i]])*theta.null[t.d[i]])), na.rm=T)/n.obs;
  };
  
  return(c(F.log2.0, F.log2.1, F.d.0, F.d.1));
};

e.F.ols <- t(sapply(1:length(ys.ols), PDR.F.null, model.spec=model.spec, data.loca=trade.data, ys=ys.ols, theta.null=theta.ols,
                  t.log2=t.log2, t.d=t.d));

F.name <- c(paste("F.",X.name[t.log2],".0",sep=""), paste("F.",X.name[t.log2],".1",sep=""),
            paste("F.",X.name[t.d],".0",sep=""), paste("F.",X.name[t.d],".1",sep=""));

colnames(e.F.ols) <- F.name;



#########################
# Tobit Null Parameters #
#########################
trade.data$ytrim <- trade.data[,Y.name];
trade.data$ytrim[trade.data$ytrim>ys[which(taus==0.95)]] <- ys[which(taus==0.95)];
model.spec.trim <- update(model.spec, ytrim ~.);
library(AER);
tobit.model <- tobit(model.spec.trim, left=0, right=Inf, dist="gaussian", subset=NULL, data=trade.data, control=list(maxiter=300));
sigma.tobit <- tobit.model$scale;
theta.tobit <- coefficients(tobit.model)/sigma.tobit*pi/sqrt(3);
ys.tobit <- ys/sigma.tobit*pi/sqrt(3);


e.F.tobit <- t(sapply(1:length(ys.tobit), PDR.F.null, model.spec=model.spec, data.loca=trade.data, ys=ys.tobit, theta.null=theta.tobit,
                    t.log2=t.log2, t.d=t.d));
colnames(e.F.tobit) <- F.name;


save.image("Simulation_nullpara.RData");
